@@ -1,8 +1,10 @@
 from builder import *
 from browser import *
+from star_browser import *
 
 __all__ = [
     "SQLDenormalizer",
     "SQLBrowser",
-    "SQLWorkspace"
+    "SQLWorkspace",
+    "StarBrowser"
 ]
\ No newline at end of file
