@@ -1,9 +1,9 @@
 from slicer import Slicer, run_server
 from common import VERSION, API_VERSION
 
-__all__ = {
+__all__ = (
     "Slicer",
     "run_server",
     "VERSION",
     "API_VERSION"
-}
+)
