@@ -1,5 +1,13 @@
 """Common objects for slicer server"""
-from werkzeug.exceptions import HTTPException
+
+try:
+    from werkzeug.exceptions import HTTPException
+except:
+    # No need to bind objects here to dependency-sink, as the user
+    # will be notified when he tries to use Slicer or run_server about
+    # the missing package
+    HTTPException = object
+
 import json
 import os.path
 import decimal
@@ -7,7 +15,7 @@ import datetime
 
 TEMPLATE_PATH = os.path.join(os.path.dirname(__file__), 'templates')
 
-VERSION = "0.5"
+VERSION = "0.7"
 API_VERSION = "1"
 
 class ServerError(HTTPException):
@@ -58,7 +66,6 @@ class NotFoundError(ServerError):
 class AggregationError(ServerError):
     code = 400
 
-
 class SlicerJSONEncoder(json.JSONEncoder):
     def __init__(self, *args, **kwargs):
         """Creates a JSON encoder that will convert some data values and also allows
