@@ -221,3 +221,38 @@ def get_localizable_attributes(obj):
     except:
         pass
     return locale
+
+class MissingPackage(object):
+    """Bogus class to handle missing optional packages - packages that are not necessarily required
+    for Cubes, but are needed for certain features."""
+    
+    def __init__(self, package, feature = None, source = None, comment = None):
+        self.package = package
+        self.feature = feature
+        self.source = source
+        self.comment = comment
+
+    def __call__(self, *args, **kwargs):
+        self._fail()
+        
+    def __getattr__(self, name):
+        self._fail()
+    
+    def _fail(self):
+        if self.feature:
+            use = " to be able to use: %s" % self.feature
+        else:
+            use = ""
+            
+        if self.source:
+            source = " from %s" % self.source
+        else:
+            source = ""
+            
+        if self.comment:
+            comment = ". %s" % self.comment
+        else:
+            comment = ""
+
+        raise Exception("Optional package '%s' is not installed. Please install the package%s%s%s" % 
+                            (self.package, source, use, comment))
